plot_meanTs: Plot means of simulated T and estimated T

View source: R/plot_meanTs.R

plot_meanTsR Documentation

Plot means of simulated T and estimated T

Description

This is a wrapper function for plotting values of simulated T and true T. Means are taken within repeated values of Ni.

Usage

plot_meanTs(dat, legend, nu)

Arguments

dat

Data to be plotted

legend

Legend position; passed to legend.postion()

nu

An integer vector, the values for desired number of collars plotted on the x axis


chrisroberts2112/caribouSim documentation built on May 8, 2022, 12:05 a.m.