plot_sim: Plot rejections

View source: R/plot_sim.R

plot_simR Documentation

Plot rejections

Description

This is a wrapper function for plotting rejections from iterate for a power analysis

Usage

plot_sim(dat, legend = c("none", "top", "bottom", "left", "right"), nu, k = 9)

Arguments

dat

A csv file containing data to plot

legend

Legend position; passed to legend.postion()

nu

An integer vector, the values for desired number of collars plotted on the x axis

k

An odd integer, degree of moving average


chrisroberts2112/caribouSim documentation built on May 8, 2022, 12:05 a.m.