| plot_meanTs | R Documentation |
This is a wrapper function for plotting values of simulated T and true T. Means are taken within repeated values of Ni.
plot_meanTs(dat, legend, nu)
dat |
Data to be plotted |
legend |
Legend position; passed to legend.postion() |
nu |
An integer vector, the values for desired number of collars plotted on the x axis |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.