| plot_sim | R Documentation |
This is a wrapper function for plotting rejections from iterate for a power analysis
plot_sim(dat, legend = c("none", "top", "bottom", "left", "right"), nu, k = 9)
dat |
A csv file containing data to plot |
legend |
Legend position; passed to legend.postion() |
nu |
An integer vector, the values for desired number of collars plotted on the x axis |
k |
An odd integer, degree of moving average |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.